#!/bin/zsh

### API SCRIPT - Update Device name + Auth User ##########################################

##
## ./script.sh SERVER TOKEN CSVFILE

## Server URL (remember it is https://)
serverURL="$1"

## Filewave Autorization token (remember it ends with a =)
## pass this as the second argument. 
token="$2"

## CSV file with the serial number, device name, and auth name for each device
## Example CSV data:
## 123456,Device 1,user1@example.com
## 654321,Device 2,user2@example.com
csvFile="$3"

###########################################################################

## Check that all required arguments were passed
if [[ -z "$serverURL" || -z "$token" || -z "$csvFile" ]]; then
	echo "Error: Missing required arguments."
	echo "Usage: ./script.sh SERVER TOKEN CSVFILE"
	exit 1
fi

## Check that the Server URL begins with https://
if [[ ! "$serverURL" =~ ^https:\/\/ ]]; then
	echo "Error: Server URL incorrect (missing https://)"
	echo "Usage: ./script.sh SERVER TOKEN CSVFILE"
	exit 1
fi

## Check that the Server URL does not end with a trailing slash
if [[ "$serverURL" =~ \/$ ]]; then
	echo "Error: Server URL incorrect (remove trailing slash)"
	echo "Usage: ./script.sh SERVER TOKEN CSVFILE"
	exit 1
fi

## Check that the CSV file exists
if [[ ! -f "$csvFile" ]]; then
	echo "Error: CSV file does not exist."
	echo "Usage: ./script.sh SERVER TOKEN CSVFILE"
	exit 1
fi

## Read the CSV file and update the device name and auth user for each row
while IFS=, read -r serialNumber deviceName authName; do
	echo "Updating device with serial number $serialNumber..."
	## Contact Filewave to get the device ID
	deviceID=$( curl -skf -H "Authorization: $token" -X GET "$serverURL/api/search/v1/global?limit=1&query=$serialNumber" -H "accept: application/json" | sed -e 's/.*id":\(.*\),"url.*/\1/' )
	if [[ -z "$deviceID" || "$deviceID" == "[]" ]]; then
		## If the device ID was not found
		echo "Device not detected in Filewave database. Be sure you have the server URL and token right."
	else
		## If the device ID was found
		echo "Device ID is $deviceID"
		echo "Device Name will be $deviceName"
		echo "Device AuthName will be $authName"

		curl -s -X PATCH "$serverURL/filewave/api/devices/v1/devices/$deviceID" \
		-H "Authorization: $token" \
		-H 'cache-control: no-cache' \
		-H 'content-type: application/json' \
		-d "{\"name\":\"$deviceName\"}" > /dev/null

		curl -s -X PATCH "$serverURL/filewave/api/devices/v1/devices/$deviceID" \
		-H "Authorization: $token" \
		-H 'cache-control: no-cache' \
		-H 'content-type: application/json' \
		-d "{\"auth_username\":\"$authName\"}" > /dev/null
	fi
done < <(tr -d '\r' < "$csvFile")

# Update the model when all done.
echo "Updating the Model to reflect changes."
curl -X POST "$serverURL/filewave/api/fwserver/update_model" \
	-H "Authorization: $token" \
	-H 'cache-control: no-cache' \
	-H 'content-type: application/json' \

echo "Process is complete!"

exit 0